<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Tiedostotyökalut</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Näytä tiedostotyökalut</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translation>Muoto:</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translation>Korvataanko tiedosto?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Tiedosto &apos;%1&apos; on jo olemassa. Haluatko korvata sen?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
